@@ -11,7 +11,7 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2006, 2009, 2010, 2012, 2015, 2018, 2019, 2021, 2022, 2024, 2025 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2006, 2009, 2010, 2012, 2015, 2018, 2019, 2021, 2022, 2024-2026 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2007 Ilmari Heikkinen <ilmari.heikkinen@gmail.com>
 // Copyright (C) 2009 Shen Liang <shenzhuxi@gmail.com>
 // Copyright (C) 2009 Stefan Thomas <thomas@eload24.com>
@@ -134,7 +134,7 @@ SplashBitmap::SplashBitmap(int widthA, int heightA, int rowPadA, SplashColorMode
 
 SplashBitmap *SplashBitmap::copy(const SplashBitmap *src)
 {
-    SplashBitmap *result = new SplashBitmap(src->getWidth(), src->getHeight(), src->getRowPad(), src->getMode(), src->getAlphaPtr() != nullptr, src->getRowSize() >= 0, src->getSeparationList());
+    auto *result = new SplashBitmap(src->getWidth(), src->getHeight(), src->getRowPad(), src->getMode(), src->getAlphaPtr() != nullptr, src->getRowSize() >= 0, src->getSeparationList());
     SplashColorConstPtr dataSource = src->getDataPtr();
     unsigned char *dataDest = result->getDataPtr();
     int amount = src->getRowSize();
@@ -168,13 +168,12 @@ SplashBitmap::~SplashBitmap()
 SplashError SplashBitmap::writePNMFile(char *fileName)
 {
     FILE *f;
-    SplashError e;
 
     if (!(f = openFile(fileName, "wb"))) {
-        return splashErrOpenFile;
+        return SplashError::OpenFile;
     }
 
-    e = this->writePNMFile(f);
+    const SplashError e = this->writePNMFile(f);
 
     fclose(f);
     return e;
@@ -252,10 +251,10 @@ SplashError SplashBitmap::writePNMFile(FILE *f)
     case splashModeDeviceN8:
         // PNM doesn't support CMYK
         error(errInternal, -1, "unsupported SplashBitmap mode");
-        return splashErrGeneric;
+        return SplashError::Generic;
         break;
     }
-    return splashOk;
+    return SplashError::NoError;
 }
 
 SplashError SplashBitmap::writeAlphaPGMFile(char *fileName)
@@ -263,15 +262,15 @@ SplashError SplashBitmap::writeAlphaPGMFile(char *fileName)
     FILE *f;
 
     if (!alpha) {
-        return splashErrModeMismatch;
+        return SplashError::ModeMismatch;
     }
     if (!(f = openFile(fileName, "wb"))) {
-        return splashErrOpenFile;
+        return SplashError::OpenFile;
     }
     fprintf(f, "P5\n%d %d\n255\n", width, height);
     fwrite(alpha, 1, width * height, f);
     fclose(f);
-    return splashOk;
+    return SplashError::NoError;
 }
 
 void SplashBitmap::getPixel(int x, int y, SplashColorPtr pixel) const
@@ -342,13 +341,12 @@ SplashColorPtr SplashBitmap::takeData()
 SplashError SplashBitmap::writeImgFile(SplashImageFileFormat format, const char *fileName, double hDPI, double vDPI, WriteImgParams *params)
 {
     FILE *f;
-    SplashError e;
 
     if (!(f = openFile(fileName, "wb"))) {
-        return splashErrOpenFile;
+        return SplashError::OpenFile;
     }
 
-    e = writeImgFile(format, f, hDPI, vDPI, params);
+    const SplashError e = writeImgFile(format, f, hDPI, vDPI, params);
 
     fclose(f);
     return e;
@@ -373,7 +371,6 @@ void SplashBitmap::setJpegParams(ImgWriter *writer, WriteImgParams *params)
 SplashError SplashBitmap::writeImgFile(SplashImageFileFormat format, FILE *f, double hDPI, double vDPI, WriteImgParams *params)
 {
     ImgWriter *writer;
-    SplashError e;
 
     SplashColorMode imageWriterFormat = splashModeRGB8;
 
@@ -432,10 +429,10 @@ SplashError SplashBitmap::writeImgFile(SplashImageFileFormat format, FILE *f, do
         // Not the greatest error message, but users of this function should
         // have already checked whether their desired format is compiled in.
         error(errInternal, -1, "Support for this image type not compiled in");
-        return splashErrGeneric;
+        return SplashError::Generic;
     }
 
-    e = writeImgFile(writer, f, hDPI, vDPI, imageWriterFormat);
+    const SplashError e = writeImgFile(writer, f, hDPI, vDPI, imageWriterFormat);
     delete writer;
     return e;
 }
@@ -600,7 +597,7 @@ bool SplashBitmap::convertToXBGR(ConversionMode conversionMode)
     }
 
     int newrowSize = width * 4;
-    SplashColorPtr newdata = (SplashColorPtr)gmallocn_checkoverflow(newrowSize, height);
+    auto *newdata = (SplashColorPtr)gmallocn_checkoverflow(newrowSize, height);
     if (newdata != nullptr) {
         for (int y = 0; y < height; y++) {
             unsigned char *row = newdata + y * newrowSize;
@@ -663,18 +660,18 @@ SplashError SplashBitmap::writeImgFile(ImgWriter *writer, FILE *f, double hDPI,
 {
     if (mode != splashModeRGB8 && mode != splashModeMono8 && mode != splashModeMono1 && mode != splashModeXBGR8 && mode != splashModeBGR8 && mode != splashModeCMYK8 && mode != splashModeDeviceN8) {
         error(errInternal, -1, "unsupported SplashBitmap mode");
-        return splashErrGeneric;
+        return SplashError::Generic;
     }
 
     if (!writer->init(f, width, height, hDPI, vDPI)) {
-        return splashErrGeneric;
+        return SplashError::Generic;
     }
 
     switch (mode) {
     case splashModeCMYK8:
         if (writer->supportCMYK()) {
             SplashColorPtr row;
-            unsigned char **row_pointers = new unsigned char *[height];
+            auto **row_pointers = new unsigned char *[height];
             row = data;
 
             for (int y = 0; y < height; ++y) {
@@ -683,16 +680,16 @@ SplashError SplashBitmap::writeImgFile(ImgWriter *writer, FILE *f, double hDPI,
             }
             if (!writer->writePointers(row_pointers, height)) {
                 delete[] row_pointers;
-                return splashErrGeneric;
+                return SplashError::Generic;
             }
             delete[] row_pointers;
         } else {
-            unsigned char *row = new unsigned char[3 * width];
+            auto *row = new unsigned char[3 * width];
             for (int y = 0; y < height; y++) {
                 getRGBLine(y, row);
                 if (!writer->writeRow(&row)) {
                     delete[] row;
-                    return splashErrGeneric;
+                    return SplashError::Generic;
                 }
             }
             delete[] row;
@@ -700,22 +697,22 @@ SplashError SplashBitmap::writeImgFile(ImgWriter *writer, FILE *f, double hDPI,
         break;
     case splashModeDeviceN8:
         if (writer->supportCMYK()) {
-            unsigned char *row = new unsigned char[4 * width];
+            auto *row = new unsigned char[4 * width];
             for (int y = 0; y < height; y++) {
                 getCMYKLine(y, row);
                 if (!writer->writeRow(&row)) {
                     delete[] row;
-                    return splashErrGeneric;
+                    return SplashError::Generic;
                 }
             }
             delete[] row;
         } else {
-            unsigned char *row = new unsigned char[3 * width];
+            auto *row = new unsigned char[3 * width];
             for (int y = 0; y < height; y++) {
                 getRGBLine(y, row);
                 if (!writer->writeRow(&row)) {
                     delete[] row;
-                    return splashErrGeneric;
+                    return SplashError::Generic;
                 }
             }
             delete[] row;
@@ -723,7 +720,7 @@ SplashError SplashBitmap::writeImgFile(ImgWriter *writer, FILE *f, double hDPI,
         break;
     case splashModeRGB8: {
         SplashColorPtr row;
-        unsigned char **row_pointers = new unsigned char *[height];
+        auto **row_pointers = new unsigned char *[height];
         row = data;
 
         for (int y = 0; y < height; ++y) {
@@ -732,13 +729,13 @@ SplashError SplashBitmap::writeImgFile(ImgWriter *writer, FILE *f, double hDPI,
         }
         if (!writer->writePointers(row_pointers, height)) {
             delete[] row_pointers;
-            return splashErrGeneric;
+            return SplashError::Generic;
         }
         delete[] row_pointers;
     } break;
 
     case splashModeBGR8: {
-        unsigned char *row = new unsigned char[3 * width];
+        auto *row = new unsigned char[3 * width];
         for (int y = 0; y < height; y++) {
             // Convert into a PNG row
             for (int x = 0; x < width; x++) {
@@ -749,14 +746,14 @@ SplashError SplashBitmap::writeImgFile(ImgWriter *writer, FILE *f, double hDPI,
 
             if (!writer->writeRow(&row)) {
                 delete[] row;
-                return splashErrGeneric;
+                return SplashError::Generic;
             }
         }
         delete[] row;
     } break;
 
     case splashModeXBGR8: {
-        unsigned char *row = new unsigned char[3 * width];
+        auto *row = new unsigned char[3 * width];
         for (int y = 0; y < height; y++) {
             // Convert into a PNG row
             for (int x = 0; x < width; x++) {
@@ -767,7 +764,7 @@ SplashError SplashBitmap::writeImgFile(ImgWriter *writer, FILE *f, double hDPI,
 
             if (!writer->writeRow(&row)) {
                 delete[] row;
-                return splashErrGeneric;
+                return SplashError::Generic;
             }
         }
         delete[] row;
@@ -776,7 +773,7 @@ SplashError SplashBitmap::writeImgFile(ImgWriter *writer, FILE *f, double hDPI,
     case splashModeMono8: {
         if (imageWriterFormat == splashModeMono8) {
             SplashColorPtr row;
-            unsigned char **row_pointers = new unsigned char *[height];
+            auto **row_pointers = new unsigned char *[height];
             row = data;
 
             for (int y = 0; y < height; ++y) {
@@ -785,11 +782,11 @@ SplashError SplashBitmap::writeImgFile(ImgWriter *writer, FILE *f, double hDPI,
             }
             if (!writer->writePointers(row_pointers, height)) {
                 delete[] row_pointers;
-                return splashErrGeneric;
+                return SplashError::Generic;
             }
             delete[] row_pointers;
         } else if (imageWriterFormat == splashModeRGB8) {
-            unsigned char *row = new unsigned char[3 * width];
+            auto *row = new unsigned char[3 * width];
             for (int y = 0; y < height; y++) {
                 // Convert into a PNG row
                 for (int x = 0; x < width; x++) {
@@ -800,20 +797,20 @@ SplashError SplashBitmap::writeImgFile(ImgWriter *writer, FILE *f, double hDPI,
 
                 if (!writer->writeRow(&row)) {
                     delete[] row;
-                    return splashErrGeneric;
+                    return SplashError::Generic;
                 }
             }
             delete[] row;
         } else {
             // only splashModeMono8 or splashModeRGB8
-            return splashErrGeneric;
+            return SplashError::Generic;
         }
     } break;
 
     case splashModeMono1: {
         if (imageWriterFormat == splashModeMono1) {
             SplashColorPtr row;
-            unsigned char **row_pointers = new unsigned char *[height];
+            auto **row_pointers = new unsigned char *[height];
             row = data;
 
             for (int y = 0; y < height; ++y) {
@@ -822,11 +819,11 @@ SplashError SplashBitmap::writeImgFile(ImgWriter *writer, FILE *f, double hDPI,
             }
             if (!writer->writePointers(row_pointers, height)) {
                 delete[] row_pointers;
-                return splashErrGeneric;
+                return SplashError::Generic;
             }
             delete[] row_pointers;
         } else if (imageWriterFormat == splashModeRGB8) {
-            unsigned char *row = new unsigned char[3 * width];
+            auto *row = new unsigned char[3 * width];
             for (int y = 0; y < height; y++) {
                 // Convert into a PNG row
                 for (int x = 0; x < width; x++) {
@@ -837,13 +834,13 @@ SplashError SplashBitmap::writeImgFile(ImgWriter *writer, FILE *f, double hDPI,
 
                 if (!writer->writeRow(&row)) {
                     delete[] row;
-                    return splashErrGeneric;
+                    return SplashError::Generic;
                 }
             }
             delete[] row;
         } else {
             // only splashModeMono1 or splashModeRGB8
-            return splashErrGeneric;
+            return SplashError::Generic;
         }
     } break;
 
@@ -853,8 +850,8 @@ SplashError SplashBitmap::writeImgFile(ImgWriter *writer, FILE *f, double hDPI,
     }
 
     if (!writer->close()) {
-        return splashErrGeneric;
+        return SplashError::Generic;
     }
 
-    return splashOk;
+    return SplashError::NoError;
 }
